special\_functions package
==========================

Submodules
----------

special\_functions.besselh module
---------------------------------

.. automodule:: special_functions.besselh
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.besseli module
---------------------------------

.. automodule:: special_functions.besseli
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.besselj module
---------------------------------

.. automodule:: special_functions.besselj
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.besselk module
---------------------------------

.. automodule:: special_functions.besselk
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.bessely module
---------------------------------

.. automodule:: special_functions.bessely
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.cbesselh module
----------------------------------

.. automodule:: special_functions.cbesselh
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.cbesseli module
----------------------------------

.. automodule:: special_functions.cbesseli
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.cbesselj module
----------------------------------

.. automodule:: special_functions.cbesselj
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.cbesselk module
----------------------------------

.. automodule:: special_functions.cbesselk
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.cbessely module
----------------------------------

.. automodule:: special_functions.cbessely
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.cython\_wrappers module
------------------------------------------

.. automodule:: special_functions.cython_wrappers
   :members:
   :undoc-members:
   :show-inheritance:

special\_functions.lngamma module
---------------------------------

.. automodule:: special_functions.lngamma
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: special_functions
   :members:
   :undoc-members:
   :show-inheritance:
